__all__=['', 'CreateConsoleScreenBuffer', 'GetConsoleDisplayMode', 'AttachConsole', 'AllocConsole', 'FreeConsole', 'GetConsoleProcessList', 'GetConsoleCP', 'GetConsoleOutputCP', 'SetConsoleCP', 'SetConsoleOutputCP', 'GetConsoleSelectionInfo', 'AddConsoleAlias', 'GetConsoleAliases', 'GetConsoleAliasExes', 'GetConsoleWindow', 'GetNumberOfConsoleFonts', 'SetConsoleTitle', 'GetConsoleTitle', 'GenerateConsoleCtrlEvent', 'GetStdHandle']
import typing
import win32typing
"""Interface to the Windows Console functions for dealing with character-mode applications"""


def CreateConsoleScreenBuffer(DesiredAccess:'typing.Any',ShareMode:'typing.Any',Flags:'typing.Any',SecurityAttributes:'win32typing.PySECURITY_ATTRIBUTES'=None) -> 'win32typing.PyConsoleScreenBuffer':
    """
    Creates a new console screen buffer

Args:

      DesiredAccess(typing.Any):GENERIC_READ and/or GENERIC_WRITE
      ShareMode(typing.Any):FILE_SHARE_READ and/or FILE_SHARE_WRITE
      Flags(typing.Any):CONSOLE_TEXTMODE_BUFFER is currently only valid flag
      SecurityAttributes(win32typing.PySECURITY_ATTRIBUTES):Specifies security descriptor and inheritance for handle

Returns:

      win32typing.PyConsoleScreenBuffer
        
    """
    pass
        

def GetConsoleDisplayMode() -> 'typing.Any':
    """
    Returns the current console's display mode

Args:



Returns:

      typing.Any:win32console.GetConsoleDisplayMode

int = GetConsoleDisplayMode()Returns the current console's display mode
Comments

Only exists on Wix XP and later
Return ValueCONSOLE_FULLSCREEN,CONSOLE_FULLSCREEN_HARDWARE

        
    """
    pass
        

def AttachConsole(ProcessId:'typing.Any') -> 'None':
    """
    Attaches to console of another process

Args:

      ProcessId(typing.Any):Pid of another process, or ATTACH_PARENT_PROCESSCommentsCalling process must not already be attached to another console

Returns:

      None
        
    """
    pass
        

def AllocConsole() -> 'None':
    """
    Creates a new console for the calling process

Args:



Returns:

      None
        
    """
    pass
        

def FreeConsole() -> 'None':
    """
    Detaches process from its current console

Args:



Returns:

      None
        
    """
    pass
        

def GetConsoleProcessList() -> 'typing.Tuple[typing.Any, ...]':
    """
    Returns pids of all processes attached to current console

Args:



Returns:

      typing.Tuple[typing.Any, ...]
        
    """
    pass
        

def GetConsoleCP() -> 'typing.Any':
    """
    Returns the input code page for calling process's console

Args:



Returns:

      typing.Any
        
    """
    pass
        

def GetConsoleOutputCP() -> 'typing.Any':
    """
    Returns the output code page for calling process's console

Args:



Returns:

      typing.Any
        
    """
    pass
        

def SetConsoleCP(CodePageId:'typing.Any') -> 'None':
    """
    Sets the input code page for calling process's console

Args:

      CodePageId(typing.Any):The code page to set

Returns:

      None
        
    """
    pass
        

def SetConsoleOutputCP(CodePageID:'typing.Any') -> 'None':
    """
    Sets the output code page for calling process's console

Args:

      CodePageID(typing.Any):The code page to set

Returns:

      None
        
    """
    pass
        

def GetConsoleSelectionInfo() -> 'typing.Any':
    """
    Returns info on text selection within the current console

Args:



Returns:

      typing.Any:win32console.GetConsoleSelectionInfo

dict = GetConsoleSelectionInfo()Returns info on text selection within the current console
Return ValueReturns a dictionary containing {Flags:int, SelectionAnchor: PyCOORD, Selection:PySMALL_RECT} 

Flags will contain a combination of 

CONSOLE_NO_SELECTION,CONSOLE_SELECTION_IN_PROGRESS,CONSOLE_SELECTION_NOT_EMPTY,CONSOLE_MOUSE_SELECTION,CONSOLE_MOUSE_DOWN

        
    """
    pass
        

def AddConsoleAlias(Source:'typing.Any',Target:'typing.Any',ExeName:'typing.Any') -> 'None':
    """
    Creates a new console alias

Args:

      Source(typing.Any):The string to be mapped to the target string
      Target(typing.Any):String to be substituted for Source.  If None, alias is removed
      ExeName(typing.Any):Name of executable that will use alias

Returns:

      None
        
    """
    pass
        

def GetConsoleAliases(ExeName:'typing.Any') -> 'typing.Any':
    """
    Retrieves aliases defined under specified executable

Args:

      ExeName(typing.Any):Name of executable for which to return aliasesReturn ValueReturns a unicode string containing null-terminated pairs of aliases and their target text of the form "alias1=replacementtext1\\0alias2=replacementtext2\\0"

Returns:

      typing.Any:Name of executable for which to return aliasesReturn ValueReturns a unicode string containing null-terminated pairs of aliases and their target text 

of the form "alias1=replacementtext1\\0alias2=replacementtext2\\0"

        
    """
    pass
        

def GetConsoleAliasExes() -> 'typing.Any':
    """
    Lists all executables that have console aliases defined

Args:



Returns:

      typing.Any:win32console.GetConsoleAliasExes
PyUNICODE = GetConsoleAliasExes()Lists all executables that have console aliases defined
Return ValueReturns a unicode string containing executable names separated by NULLS

        
    """
    pass
        

def GetConsoleWindow() -> 'typing.Any':
    """
    Returns a handle to the console's window, or 0 if none exists

Args:



Returns:

      typing.Any:win32console.GetConsoleWindow

int = GetConsoleWindow()Returns a handle to the console's window, or 0 if none exists
Return ValueThis function may raise NotImplementedError if it does not exist on 

the platform, or a PyHANDLE object with a value of 0.  It will never 

raise a win32 exception.

        
    """
    pass
        

def GetNumberOfConsoleFonts() -> 'typing.Any':
    """
    Returns the number of fonts available to the console

Args:



Returns:

      typing.Any
        
    """
    pass
        

def SetConsoleTitle(ConsoleTitle:'typing.Any') -> 'None':
    """
    Sets the title of the console window

Args:

      ConsoleTitle(typing.Any):New title for the console

Returns:

      None
        
    """
    pass
        

def GetConsoleTitle() -> 'typing.Any':
    """
    Returns the title of the console window

Args:



Returns:

      typing.Any
        
    """
    pass
        

def GenerateConsoleCtrlEvent(CtrlEvent:'typing.Any',ProcessGroupId:'typing.Any'=0) -> 'None':
    """
    Sends a control signal to a group of processes attached to a common 

console

Args:

      CtrlEvent(typing.Any):Signal to be sent to specified process group - CTRL_C_EVENT or CTRL_BREAK_EVENT
      ProcessGroupId(typing.Any):Pid of a process group, use 0 for calling process

Returns:

      None
        
    """
    pass
        

def GetStdHandle(StdHandle:'typing.Any') -> 'win32typing.PyConsoleScreenBuffer':
    """
    Returns one of calling process's standard handles

Args:

      StdHandle(typing.Any):Specifies the handle to return - STD_INPUT_HANDLE, STD_OUTPUT_HANDLE, or STD_ERROR_HANDLEReturn ValueReturns a PyConsoleScreenBuffer wrapping the handle, or None if specified handle does not exist

Returns:

      win32typing.PyConsoleScreenBuffer:Specifies the handle to return - 

STD_INPUT_HANDLE, STD_OUTPUT_HANDLE, or STD_ERROR_HANDLEReturn ValueReturns a PyConsoleScreenBuffer wrapping the handle, or None if specified handle does not exist

        
    """
    pass
        


__all__=['', 'HrGetExchangeStatus', 'HrGetMailboxDN', 'HrGetServerDN', 'HrMAPIFindDefaultMsgStore', 'HrMAPIFindIPMSubtree', 'HrMAPIFindInbox', 'HrMAPIFindSubfolderEx', 'HrMAPIFindFolder', 'HrMAPIFindFolderEx', 'HrMAPIFindStore', 'HrCreateProfileName', 'HrCreateDirEntryIdEx', 'HrFindExchangeGlobalAddressList', 'HrMailboxLogon', 'HrMailboxLogoff', 'HrMAPIOpenFolderEx', 'HrMAPISetPropBoolean', 'HrMAPISetPropLong', 'HrOpenExchangePublicStore', 'HrOpenExchangePrivateStore', 'HrOpenExchangePublicFolders', 'HrOpenSessionObject', 'HrOpenSiteContainer', 'HrOpenSiteContainerAddressing', 'OPENSTORE_HOME_LOGON', 'OPENSTORE_OVERRIDE_HOME_MDB', 'OPENSTORE_PUBLIC', 'OPENSTORE_TAKE_OWNERSHIP', 'OPENSTORE_USE_ADMIN_PRIVILEGE']
import typing
import win32typing
"""A COM interface to Exchange's API"""


def HrGetExchangeStatus(server:'typing.Union[str]') -> 'typing.Tuple[typing.Any, typing.Any]':
    """
    Obtains the current state of the server on a computer.

Args:

      server(typing.Union[str]):The name of the server to query.Return ValueThe result is a tuple of serviceState, serverState

Returns:

      typing.Tuple[typing.Any, typing.Any]:The name of the server to query.Return ValueThe result is a tuple of serviceState, serverState

        
    """
    pass
        

def HrGetMailboxDN(session:'typing.Any') -> 'str':
    """
    Retrieves the distinguished name (DN) for a mailbox

Args:

      session(typing.Any):The root folder.

Returns:

      str
        
    """
    pass
        

def HrGetServerDN(session:'typing.Any') -> 'str':
    """
    Retrieves the distinguished name (DN) for a server

Args:

      session(typing.Any):The root folder.

Returns:

      str
        
    """
    pass
        

def HrMAPIFindDefaultMsgStore(session:'win32typing.PyIMAPISession') -> 'str':
    """
    Retrieves the entry identifier of the default information store.

Args:

      session(win32typing.PyIMAPISession):

Returns:

      str
        
    """
    pass
        

def HrMAPIFindIPMSubtree(msgStore:'win32typing.PyIMsgStore') -> 'str':
    """
    Retrieves the entry ID of the IPM (interpersonal message) subtree folder

Args:

      msgStore(win32typing.PyIMsgStore):

Returns:

      str
        
    """
    pass
        

def HrMAPIFindInbox(msgStore:'win32typing.PyIMsgStore') -> 'str':
    """
    Retrieves the Entry ID of the IPM inbox folder

Args:

      msgStore(win32typing.PyIMsgStore):

Returns:

      str
        
    """
    pass
        

def HrMAPIFindSubfolderEx(rootFolder:'win32typing.PyIMAPIFolder',sep:'typing.Union[str]',name:'typing.Union[str]') -> 'win32typing.PyIMsgStore':
    """
    Retrieves a subfolder in an information store using the hierarchical path name of the folder.

Args:

      rootFolder(win32typing.PyIMAPIFolder):The root folder.
      sep(typing.Union[str]):The folder seperator character.
      name(typing.Union[str]):The folder name

Returns:

      win32typing.PyIMsgStore
        
    """
    pass
        

def HrMAPIFindFolder(folder:'win32typing.PyIMAPIFolder',name:'str') -> 'str':
    """
    Retrieves the entry ID for a folder in an information store using the hierarchical path name of the folder.

Args:

      folder(win32typing.PyIMAPIFolder):The folder to search
      name(str):Name of the folder

Returns:

      str
        
    """
    pass
        

def HrMAPIFindFolderEx(msgStore:'win32typing.PyIMsgStore',sepString:'str',path:'str') -> 'str':
    """
    Retrieves the entry ID of a folder in an information store using the hierarchical path name of the folder.

Args:

      msgStore(win32typing.PyIMsgStore):The folder to search
      sepString(str):The character seperating the folder names - eg '\\'
      path(str):Path to the folder

Returns:

      str
        
    """
    pass
        

def HrMAPIFindStore(session:'win32typing.PyIMAPISession',name:'str') -> 'win32typing.PyIMsgStore':
    """
    Retrieves a pointer to the entry identifier of an information store from the display name of the store.

Args:

      session(win32typing.PyIMAPISession):
      name(str):

Returns:

      win32typing.PyIMsgStore
        
    """
    pass
        

def HrCreateProfileName(profPrefix:'typing.Union[str]') -> 'str':
    """
    Creates a profile with the specified name

Args:

      profPrefix(typing.Union[str]):A prefix for the new profile.

Returns:

      str
        
    """
    pass
        

def HrCreateDirEntryIdEx(addrBook:'win32typing.PyIAddrBook',distinguishedName:'str') -> 'str':
    """
    Creates a directory identifier for a MAPI object, given the address of the object in the directory

Args:

      addrBook(win32typing.PyIAddrBook):The address book interface
      distinguishedName(str):The dn of the object to obtain the entry ID for.

Returns:

      str
        
    """
    pass
        

def HrFindExchangeGlobalAddressList(addrBook:'win32typing.PyIAddrBook') -> 'str':
    """
    Retrieves the entry identifier of the global address list (GAL) container in the address book.

Args:

      addrBook(win32typing.PyIAddrBook):The interface containing the address book

Returns:

      str
        
    """
    pass
        

def HrMailboxLogon(session:'win32typing.PyIMAPISession',msgStore:'win32typing.PyIMsgStore',msgStoreDN:'typing.Union[str]',mailboxDN:'typing.Union[str]') -> 'win32typing.PyIMsgStore':
    """
    Logs on a server and mailbox.

Args:

      session(win32typing.PyIMAPISession):The session object
      msgStore(win32typing.PyIMsgStore):
      msgStoreDN(typing.Union[str]):
      mailboxDN(typing.Union[str]):

Returns:

      win32typing.PyIMsgStore
        
    """
    pass
        

def HrMailboxLogoff(inbox:'win32typing.PyIMsgStore') -> 'None':
    """
    Logs off a server and mailbox.

Args:

      inbox(win32typing.PyIMsgStore):The open inbox.

Returns:

      None
        
    """
    pass
        

def HrMAPIOpenFolderEx(msgStore:'win32typing.PyIMsgStore',sep:'typing.Union[str]',name:'typing.Union[str]') -> 'win32typing.PyIMAPIFolder':
    """
    Opens a folder in the information store from the hierarchical path name of the folder.

Args:

      msgStore(win32typing.PyIMsgStore):
      sep(typing.Union[str]):The folder seperator character.
      name(typing.Union[str]):The folder name

Returns:

      win32typing.PyIMAPIFolder
        
    """
    pass
        

def HrMAPISetPropBoolean(obj:'win32typing.PyIMAPIProp',tag:'typing.Any') -> 'None':
    """
    Sets a boolean property.

Args:

      obj(win32typing.PyIMAPIProp):The object to set
      tag(typing.Any):The property tag

Returns:

      None
        
    """
    pass
        

def HrMAPISetPropLong(obj:'win32typing.PyIMAPIProp',tag:'typing.Any') -> 'None':
    """
    Sets a long property.

Args:

      obj(win32typing.PyIMAPIProp):The object to set
      tag(typing.Any):The property tag

Returns:

      None
        
    """
    pass
        

def HrOpenExchangePublicStore(session:'win32typing.PyIMAPISession') -> 'win32typing.PyIMsgStore':
    """
    Retrieves an interface to the public information store provider.

Args:

      session(win32typing.PyIMAPISession):The MAPI session object

Returns:

      win32typing.PyIMsgStore
        
    """
    pass
        

def HrOpenExchangePrivateStore(session:'win32typing.PyIMAPISession') -> 'win32typing.PyIMsgStore':
    """
    Locates the primary user information store provider.

Args:

      session(win32typing.PyIMAPISession):The MAPI session object

Returns:

      win32typing.PyIMsgStore
        
    """
    pass
        

def HrOpenExchangePublicFolders(store:'win32typing.PyIMsgStore') -> 'win32typing.PyIMAPIFolder':
    """
    Opens the root of the public folder hierarchy in the public information store.

Args:

      store(win32typing.PyIMsgStore):

Returns:

      win32typing.PyIMAPIFolder
        
    """
    pass
        

def HrOpenSessionObject(session:'win32typing.PyIMAPISession') -> 'win32typing.PyIMAPIProp':
    """
    None

Args:

      session(win32typing.PyIMAPISession):The MAPI session object

Returns:

      win32typing.PyIMAPIProp
        
    """
    pass
        

def HrOpenSiteContainer(session:'win32typing.PyIMAPISession') -> 'win32typing.PyIMAPIProp':
    """
    None

Args:

      session(win32typing.PyIMAPISession):The MAPI session object

Returns:

      win32typing.PyIMAPIProp
        
    """
    pass
        

def HrOpenSiteContainerAddressing(session:'win32typing.PyIMAPISession') -> 'win32typing.PyIMAPIProp':
    """
    None

Args:

      session(win32typing.PyIMAPISession):The MAPI session object

Returns:

      win32typing.PyIMAPIProp
        
    """
    pass
        
OPENSTORE_HOME_LOGON = ...
OPENSTORE_OVERRIDE_HOME_MDB = ...
OPENSTORE_PUBLIC = ...
OPENSTORE_TAKE_OWNERSHIP = ...
OPENSTORE_USE_ADMIN_PRIVILEGE = ...



__all__=['', 'CoInitializeEx', 'CoUninitialize', 'RegisterServiceCtrlHandler', 'LogMsg', 'LogInfoMsg', 'LogErrorMsg', 'LogWarningMsg', 'PumpWaitingMessages', 'Debugging', 'Initialize', 'Finalize', 'PrepareToHostSingle', 'PrepareToHostMultiple', 'RunningAsService', 'SetEventSourceName']
import typing
import win32typing
""""""


def CoInitializeEx() -> 'None':
    """
    Initialize OLE with additional options.

Args:



Returns:

      None
        
    """
    pass
        

def CoUninitialize() -> 'None':
    """
    Unitialize OLE

Args:



Returns:

      None
        
    """
    pass
        

def RegisterServiceCtrlHandler(serviceName:'str',callback:'typing.Any',extra_args:'typing.Any'=False) -> 'typing.Union[typing.Any]':
    """
    Registers the Python service control handler function.

Args:

      serviceName(str):The name of the service.  This is provided in args[0] of the service class __init__ method.
      callback(typing.Any):The Python function that performs as the control function.  This will be called with an integer status argument.
      extra_args(typing.Any):Is this callback expecting the additional 2 args passed by HandlerEx?Return ValueIf the service manager is in debug mode, this returns None, indicating there is no service control manager handle, otherwise the handle to the Win32 service manager.

Returns:

      typing.Union[typing.Any]:Is this callback expecting the additional 2 args passed by HandlerEx?
Return ValueIf the service manager is in debug mode, this returns None, indicating 

there is no service control manager handle, otherwise the handle to the Win32 service manager.

        
    """
    pass
        

def LogMsg(errorType:'typing.Any',eventId:'typing.Any',inserts:'typing.Tuple[str, typing.Any]'=None) -> 'None':
    """
    Logs a specific message

Args:

      errorType(typing.Any):
      eventId(typing.Any):
      inserts(typing.Tuple[str, typing.Any]):

Returns:

      None
        
    """
    pass
        

def LogInfoMsg(msg:'str') -> 'None':
    """
    Logs a generic informational message to the event log

Args:

      msg(str):The message to write.

Returns:

      None
        
    """
    pass
        

def LogErrorMsg(msg:'str') -> 'None':
    """
    Logs a generic error message to the event log

Args:

      msg(str):The message to write.

Returns:

      None
        
    """
    pass
        

def LogWarningMsg(msg:'str') -> 'None':
    """
    Logs a generic warning message to the event log

Args:

      msg(str):The message to write.

Returns:

      None
        
    """
    pass
        

def PumpWaitingMessages() -> 'typing.Any':
    """
    Pumps all waiting messages.

Args:



Returns:

      typing.Any:servicemanager.PumpWaitingMessages

int = PumpWaitingMessages()Pumps all waiting messages.
Return ValueReturns 1 if a WM_QUIT message was received, else 0

        
    """
    pass
        

def Debugging(newVal:'typing.Any'=-1) -> 'typing.Union[typing.Any]':
    """
    Indicates if the service is running in debug mode 

and optionally toggles the debug flag.

Args:

      newVal(typing.Any):If not -1, a new value for the debugging flag. The result is the value of the flag before it is changed.

Returns:

      typing.Union[typing.Any]
        
    """
    pass
        

def Initialize(eventSourceName:'str'=None,eventSourceFile:'str'=None) -> 'None':
    """
    Initialize the module for hosting a service.  This is generally called 

automatically

Args:

      eventSourceName(str):The event source name
      eventSourceFile(str):The name of the file (generally a DLL) with the event source messages.

Returns:

      None
        
    """
    pass
        

def Finalize() -> 'None':
    """
    None

Args:



Returns:

      None
        
    """
    pass
        

def PrepareToHostSingle(klass:'typing.Any'=None) -> 'None':
    """
    Prepare for hosting a single service in this EXE

Args:

      klass(typing.Any):The Python class to host.  If not specified, the service name is looked up in the registry and the specified class instantiated.

Returns:

      None
        
    """
    pass
        

def PrepareToHostMultiple(service_name:'typing.Union[str, typing.Any]',klass:'typing.Any') -> 'None':
    """
    Prepare for hosting a multiple services in this EXE

Args:

      service_name(typing.Union[str, typing.Any]):The name of the service hosted by the class
      klass(typing.Any):The Python class to host.

Returns:

      None
        
    """
    pass
        

def RunningAsService() -> 'typing.Union[typing.Any]':
    """
    Indicates if the code is 

being executed as a service.

Args:



Returns:

      typing.Union[typing.Any]
        
    """
    pass
        

def SetEventSourceName(sourceName:'str',registerNow:'typing.Any'=False) -> 'None':
    """
    Sets the event source name 

for event log entries written by the service.

Args:

      sourceName(str):The event source name
      registerNow(typing.Any):If True, the event source name in the registry will be updated immediately. If False, the name will be registered the first time an event log entry is written via any pythonservice methods (or possibly never if no record if written). Note that in some cases, the service itself will not have permission to write the event source in the registry.  Therefore, it would be prudent for your installation program to call this function with registerNow=True, to ensure your services can write useful entries.

Returns:

      None
        
    """
    pass
        


# -*- coding: utf-8 -*-
import os
from setuptools import setup, find_packages
from distutils import sysconfig
import sys

try:
    long_description = open("README.rst").read()
except IOError:
    long_description = ""


setup(
    name="pywin32-stubs",
    version="1.0.7",
    description="stubs for pywin32",
    license="MIT",
    url=" https://pypi.org/project/pywin32-stubs/",
    author="Carlos Teng",
    author_email ="303359166@qq.com",
    keywords=["pywin32", "stubs"],
    packages=["win32-stubs", "pythonwin-stubs", "win32comext-stubs", "win32helper"],
    package_data={
        "win32-stubs":["*.py", "*.pyi"],
        "pythonwin-stubs":["*.py", "*.pyi"],
        "win32comext-stubs":["*.py", "*.pyi"],
        "win32helper":["*.py", "*.pyi"]
        },
    data_files=[("Lib/site-packages",["pywin32-stubs.pth"])],
    install_requires=['pywin32'],
    long_description=long_description,
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.6",
    ],
    zip_safe=False
)



__all__=['', 'AddCounter', 'AddEnglishCounter', 'RemoveCounter', 'EnumObjectItems', 'EnumObjects', 'OpenQuery', 'CloseQuery', 'MakeCounterPath', 'GetCounterInfo', 'GetFormattedCounterValue', 'CollectQueryData', 'ValidatePath', 'ExpandCounterPath', 'ParseCounterPath', 'ParseInstanceName', 'SetCounterScaleFactor', 'BrowseCounters', 'ConnectMachine', 'LookupPerfIndexByName', 'LookupPerfNameByIndex']
import typing
import win32typing
"""A module, encapsulating the Windows Performance Data Helpers API"""


def AddCounter(hQuery:'typing.Any',path:'str',userData:'typing.Any'=0) -> 'typing.Any':
    """
    Adds a new counter

Args:

      hQuery(typing.Any):Handle to an open query.
      path(str):Full path to the performance data
      userData(typing.Any):User data associated with the counter.CommentsSee also win32pdh::RemoveCounter

Returns:

      typing.Any
        
    """
    pass
        

def AddEnglishCounter(hQuery:'typing.Any',path:'str',userData:'typing.Any'=0) -> 'typing.Any':
    """
    Adds a counter to a query by its English name

Args:

      hQuery(typing.Any):Handle to an open query.
      path(str):Full counter path with standard English names.
      userData(typing.Any):User data associated with the counter.CommentsAvailable on Vista and laterSee also win32pdh::RemoveCounterReturn ValueReturns a handle to the counter

Returns:

      typing.Any:User data associated with the counter.
Comments

Available on Vista and later

See also win32pdh::RemoveCounter
Return ValueReturns a handle to the counter

        
    """
    pass
        

def RemoveCounter(handle:'typing.Any') -> 'None':
    """
    Removes a previously opened counter

Args:

      handle(typing.Any):Handle to an open counter.CommentsSee also win32pdh::AddCounter

Returns:

      None
        
    """
    pass
        

def EnumObjectItems(DataSource:'str',machine:'str',_object:'str',detailLevel:'typing.Any',flags:'typing.Any'=0) -> 'typing.Any':
    """
    Enumerates an object's items

Args:

      DataSource(str):Path of a performance log file, or None for machine counters
      machine(str):The machine to use, or None
      _object(str):The type of object
      detailLevel(typing.Any):The level of data required, win32pdh.PERF_DETAIL_*
      flags(typing.Any):Flags - must be zero

Returns:

      typing.Any
        
    """
    pass
        

def EnumObjects(DataSource:'str',machine:'str',detailLevel:'typing.Any',refresh:'typing.Any'=1) -> 'typing.Any':
    """
    Enumerates objects

Args:

      DataSource(str):Path to a performance log file, or None for machine counters
      machine(str):The machine to use, or None
      detailLevel(typing.Any):The level of data required.
      refresh(typing.Any):Should the list be refreshed.

Returns:

      typing.Any
        
    """
    pass
        

def OpenQuery(DataSource:'typing.Any'=None,userData:'typing.Any'=0) -> 'typing.Any':
    """
    Opens a new query

Args:

      DataSource(typing.Any):Name of a performaance log file, or None for live data
      userData(typing.Any):User data associated with the query.CommentsSee also win32pdh::CloseQuery

Returns:

      typing.Any
        
    """
    pass
        

def CloseQuery(handle:'typing.Any') -> 'None':
    """
    Closes a query

Args:

      handle(typing.Any):Handle to an open query.CommentsSee also win32pdh::OpenQuery

Returns:

      None
        
    """
    pass
        

def MakeCounterPath(elements:'typing.Tuple[typing.Any, typing.Any, typing.Any, typing.Any, typing.Any, typing.Any]',flags:'typing.Any'=0) -> 'None':
    """
    Makes a fully resolved counter path

Args:

      elements(typing.Tuple[typing.Any, typing.Any, typing.Any, typing.Any, typing.Any, typing.Any]):The elements to use to create the path.
      flags(typing.Any):PDH_PATH_WBEM_RESULT, PDH_PATH_WBEM_INPUT, or 0

Returns:

      None
        
    """
    pass
        

def GetCounterInfo(handle:'typing.Any',bRetrieveExplainText:'typing.Any') -> 'None':
    """
    Retrieves information about a counter, such as data size, counter type, path, and 

user-supplied data values.

Args:

      handle(typing.Any):The handle of the item to query
      bRetrieveExplainText(typing.Any):Should explain text be retrieved?

Returns:

      None
        
    """
    pass
        

def GetFormattedCounterValue(handle:'typing.Any',_format:'typing.Any') -> 'typing.Tuple[typing.Any, typing.Any]':
    """
    Retrieves a formatted counter value

Args:

      handle(typing.Any):Handle to the counter
      _format(typing.Any):Format of result.  Can be PDH_FMT_DOUBLE, PDH_FMT_LARGE, PDH_FMT_LONG and or'd with PDH_FMT_NOSCALE, PDH_FMT_1000

Returns:

      typing.Tuple[typing.Any, typing.Any]
        
    """
    pass
        

def CollectQueryData(hQuery:'typing.Any') -> 'None':
    """
    Collects the current raw data value for all counters in the specified query and 

updates the status code of each counter.

Args:

      hQuery(typing.Any):Handle to an open query.

Returns:

      None
        
    """
    pass
        

def ValidatePath(path:'str') -> 'typing.Any':
    """
    Validates that the specified counter is present on the machine specified in the 

counter path.

Args:

      path(str):The counter path to validate.CommentsThis method returns an integer result code.  No exception is ever thrown.  Zero result indicates success.

Returns:

      typing.Any
        
    """
    pass
        

def ExpandCounterPath(wildCardPath:'str') -> 'typing.Tuple[typing.Any, typing.Any]':
    """
    Examines the specified machine (or local machine if none is specified) 

for counters and instances of counters that match the wild card strings in the counter path.

Args:

      wildCardPath(str):The counter path to expand.CommentsThe counter path format is assumed to be: \\machine\\object(parent/instance#index)\\countername and the parent, instance, index, and countername elements may contain either a valid name or a wild card character.The API function leaks memory on Windows XP.

Returns:

      typing.Tuple[typing.Any, typing.Any]
        
    """
    pass
        

def ParseCounterPath(path:'str',flags:'typing.Any'=0) -> 'typing.Tuple[typing.Any, typing.Any, typing.Any, typing.Any, typing.Any, typing.Any]':
    """
    Parses the elements of the counter path.

Args:

      path(str):The counter path to parse.
      flags(typing.Any):Reserved - must be zero.

Returns:

      typing.Tuple[typing.Any, typing.Any, typing.Any, typing.Any, typing.Any, typing.Any]
        
    """
    pass
        

def ParseInstanceName(instanceName:'str') -> 'typing.Tuple[typing.Any, typing.Any, typing.Any]':
    """
    Parses the elements of the instance name

Args:

      instanceName(str):The instance name to parse.

Returns:

      typing.Tuple[typing.Any, typing.Any, typing.Any]
        
    """
    pass
        

def SetCounterScaleFactor(hCounter:'typing.Any',factor:'typing.Any') -> 'None':
    """
    Sets the scale factor that is applied to the calculated value of the 

specified counter when you request the formatted counter value.

Args:

      hCounter(typing.Any):Handle to the counter.
      factor(typing.Any):power of ten used to multiply value.

Returns:

      None
        
    """
    pass
        

def BrowseCounters(Flags:'typing.Tuple[typing.Any, ...]',hWndOwner:'int',CallBack:'typing.Any',DefaultDetailLevel:'typing.Any',DialogBoxCaption:'str'=None,InitialPath:'typing.Any'=None,DataSource:'typing.Any'=None,ReturnMultiple:'typing.Any'=False,CallBackArg:'typing.Any'=None) -> 'str':
    """
    Displays the counter browsing dialog box so that the user can select the 

counters to be returned to the caller.

Args:

      Flags(typing.Tuple[typing.Any, ...]):Sequence of boolean flags, or None. All default to False. (bIncludeInstanceIndex, bSingleCounterPerAdd, bSingleCounterPerDialog, bLocalCountersOnly, bWildCardInstances, bHideDetailBox, bInitializePath, bDisableMachineSelection, bIncludeCostlyObjects, bShowObjectBrowser)
      hWndOwner(int):Parent for the dialog.
      CallBack(typing.Any):A callable object to function as the callback.
      DefaultDetailLevel(typing.Any):The default detail level to show on startup in the Detail Level combo box. If the Detail Level combo box is not shown, this is the detail level to use in filtering the displayed performance counters and objects.
      DialogBoxCaption(str):The dialog caption, or None for default.
      InitialPath(typing.Any):Counter to be selected initially, or None for default
      DataSource(typing.Any):Name of a performance log file, or None for live counters
      ReturnMultiple(typing.Any):Return all selected counter paths as a sequence of strings. Previously, this function only returned a single path even when multiple counters were selected.
      CallBackArg(typing.Any):Extra argument to be passed to callback function. For backward compatibility, the callback will only receive a single argument if this is not given.

Returns:

      str
        
    """
    pass
        

def ConnectMachine(machineName:'str') -> 'str':
    """
    connects to the specified machine, and creates and initializes a machine 

entry in the PDH DLL.

Args:

      machineName(str):The machine name.

Returns:

      str
        
    """
    pass
        

def LookupPerfIndexByName(machineName:'str',instanceName:'str') -> 'typing.Any':
    """
    Returns the counter index corresponding to the specified counter name.

Args:

      machineName(str):The name of the machine where the specified counter is located. The machine name can be specified by the DNS name or the IP address.
      instanceName(str):The full name of the counter.

Returns:

      typing.Any
        
    """
    pass
        

def LookupPerfNameByIndex(machineName:'str',index:'typing.Any') -> 'str':
    """
    Returns the performance object name corresponding to the specified 

index.

Args:

      machineName(str):The name of the machine where the specified counter is located. The machine name can be specified by the DNS name or the IP address.
      index(typing.Any):The index of the performance object.

Returns:

      str
        
    """
    pass
        


__all__=['', 'CredMarshalCredential', 'CredUnmarshalCredential', 'CredIsMarshaledCredential', 'CredEnumerate', 'CredGetTargetInfo', 'CredWriteDomainCredentials', 'CredReadDomainCredentials', 'CredDelete', 'CredWrite', 'CredRead', 'CredRename', 'CredUICmdLinePromptForCredentials', 'CredUIPromptForCredentials', 'CredUIConfirmCredentials', 'CredUIReadSSOCredW', 'CredUIStoreSSOCredW', 'CredUIParseUserName']
import typing
import win32typing
""""""


def CredMarshalCredential(CredType:'typing.Any',Credential:'typing.Union[str, typing.Any]') -> 'str':
    """
    Marshals a credential into a unicode string

Args:

      CredType(typing.Any):CertCredential or UsernameTargetCredential
      Credential(typing.Union[str, typing.Any]):The credential to be marshalled.  Type is dependent on CredType.CredTypeType of CredentialCertCredentialString containing the SHA1 hash of user's certificateUsernameTargetCredentialUnicode string containing a username for which credentials exist in current logon sessionCommentsCredentials with Flags that contain CRED_FLAGS_USERNAME_TARGET can be marshalled to be passed as the username to functions that normally require a username/password combination, such as win32security::LogonUser and win32net::NetUseAdd

Returns:

      str
        
    """
    pass
        

def CredUnmarshalCredential(MarshaledCredential:'str') -> 'typing.Tuple[typing.Any, str]':
    """
    None

Args:

      MarshaledCredential(str):Unicode string containing marshaled credentialCredTypeType of output credentialsCertCredentialCharacter string containing SHA1 hash of a certificateUsernameTargetCredentialUnicode string containing usernameReturn ValueReturns the credential type and credentials.

Returns:

      typing.Tuple[typing.Any, str]:Unicode string 

containing marshaled credential


CredType


Type of output credentials



CertCredentialCharacter string containing SHA1 hash of a certificate
UsernameTargetCredentialUnicode string containing username
Return ValueReturns the credential type and credentials.

        
    """
    pass
        

def CredIsMarshaledCredential(MarshaledCredential:'str') -> 'typing.Any':
    """
    Checks if a string matches the form of a marshaled credential

Args:

      MarshaledCredential(str):Marshaled credential as returned by win32cred::CredMarshalCredential

Returns:

      typing.Any
        
    """
    pass
        

def CredEnumerate(Filter:'str'=None,Flags:'typing.Any'=0) -> 'typing.Tuple[typing.Any, ...]':
    """
    Lists credentials for current logon session

Args:

      Filter(str):Matches credentials' target names by prefix, can be None
      Flags(typing.Any):Reserved, use 0 if passed inReturn ValueReturns a sequence of PyCREDENTIAL dictionaries

Returns:

      typing.Tuple[typing.Any, ...]:Reserved, use 0 if passed in
Return ValueReturns a sequence of PyCREDENTIAL dictionaries

        
    """
    pass
        

def CredGetTargetInfo(TargetName:'str',Flags:'typing.Any'=0) -> 'typing.Any':
    """
    Determines type and location of credential target

Args:

      TargetName(str):Name of server that is target of stored credentials
      Flags(typing.Any):CRED_ALLOW_NAME_RESOLUTION, or 0CommentsThe target information will not be available until an attempt is made to authenticate against itReturn ValueReturns a PyCREDENTIAL_TARGET_INFORMATION dict

Returns:

      typing.Any:CRED_ALLOW_NAME_RESOLUTION, or 0
Comments

The target information will not be available until an attempt is made to authenticate against it
Return ValueReturns a PyCREDENTIAL_TARGET_INFORMATION dict

        
    """
    pass
        

def CredWriteDomainCredentials(TargetInfo:'typing.Any',Credential:'typing.Any',Flags:'typing.Any'=0) -> 'None':
    """
    Creates or updates credential for a domain or server

Args:

      TargetInfo(typing.Any):PyCREDENTIAL_TARGET_INFORMATION identifying the target domain. At least one of the Names is required
      Credential(typing.Any):PyCREDENTIAL dict containing the credentials to be stored
      Flags(typing.Any):CRED_PRESERVE_CREDENTIAL_BLOB is only defined flagCommentsWhen updating a credential, to preserve a previously stored password use None or '' for CredentialBlob member of Credential and pass CRED_PRESERVE_CREDENTIAL_BLOB in Flags

Returns:

      None
        
    """
    pass
        

def CredReadDomainCredentials(TargetInfo:'typing.Any',Flags:'typing.Any'=0) -> 'typing.Tuple[typing.Any, ...]':
    """
    Retrieves credentials for a domain or server

Args:

      TargetInfo(typing.Any):PyCREDENTIAL_TARGET_INFORMATION identifying a domain or server. At least one of the Names is required.
      Flags(typing.Any):CRED_CACHE_TARGET_INFORMATION is only valid flagReturn ValueReturns a sequence of PyCREDENTIAL dicts

Returns:

      typing.Tuple[typing.Any, ...]:CRED_CACHE_TARGET_INFORMATION is only valid flag
Return ValueReturns a sequence of PyCREDENTIAL dicts

        
    """
    pass
        

def CredDelete(TargetName:'str',Type:'typing.Any',Flags:'typing.Any'=0) -> 'None':
    """
    Deletes a stored credential

Args:

      TargetName(str):Target of credential to be deleted
      Type(typing.Any):One of the CRED_TYPE_* values
      Flags(typing.Any):Reserved, use only 0

Returns:

      None
        
    """
    pass
        

def CredWrite(Credential:'typing.Any',Flags:'typing.Any'=0) -> 'None':
    """
    Creates or updates a stored credential

Args:

      Credential(typing.Any):PyCREDENTIAL dict containing the credentials to be stored
      Flags(typing.Any):CRED_PRESERVE_CREDENTIAL_BLOB is only defined flagCommentsWhen updating a credential, to preserve a previously stored password use None or '' for CredentialBlob member of Credential and pass CRED_PRESERVE_CREDENTIAL_BLOB in Flags

Returns:

      None
        
    """
    pass
        

def CredRead(TargetName:'str',Type:'typing.Any',Flags:'typing.Any'=0) -> 'typing.Any':
    """
    Retrieves a stored credential

Args:

      TargetName(str):The target of the credentials to retrieve
      Type(typing.Any):One of the CRED_TYPE_* constants
      Flags(typing.Any):Reserved, use 0Return ValueReturns a PyCREDENTIAL dict

Returns:

      typing.Any:Reserved, use 0
Return ValueReturns a PyCREDENTIAL dict

        
    """
    pass
        

def CredRename(OldTargetName:'str',NewTargetName:'str',Type:'typing.Any',Flags:'typing.Any'=0) -> 'typing.Any':
    """
    Changes the target name of stored credentials

Args:

      OldTargetName(str):The target of credential to be renamed
      NewTargetName(str):New target for the specified credential
      Type(typing.Any):Type of the credential to be renamed (CRED_TYPE_*)
      Flags(typing.Any):Reserved, use only 0CommentsCRED_FLAGS_USERNAME_TARGET credentials can't be renamed since their TargetName and Username must be equal

Returns:

      typing.Any
        
    """
    pass
        

def CredUICmdLinePromptForCredentials(TargetName:'str',Flags:'typing.Any',AuthError:'typing.Any'=0,UserName:'str'=None,Password:'str'=None,Save:'typing.Any'=True) -> 'typing.Tuple[str, str, typing.Any]':
    """
    Prompt for 

username/passwd from a console app

Args:

      TargetName(str):Server or domain against which to authenticate
      Flags(typing.Any):Combination of CREDUI_FLAGS_* valuesCommentsThe command-line version of this function does not accept certificates, so Flags must contain CREDUI_FLAGS_EXCLUDE_CERTIFICATES or CREDUI_FLAGS_REQUIRE_SMARTCARDReturn ValueReturns the username and password entered, and a boolean indicating if credential was saved
      AuthError(typing.Any):Error code indicating why credentials are required, can be 0
      UserName(str):Default username, can be None.  At most CREDUI_MAX_USERNAME_LENGTH chars
      Password(str):Password, can be None.  At most CREDUI_MAX_PASSWORD_LENGTH chars
      Save(typing.Any):Specifies default value for Save prompt

Returns:

      typing.Tuple[str, str, typing.Any]:Combination of CREDUI_FLAGS_* values
Comments

The command-line version of this function does not accept certificates, so Flags 

must contain CREDUI_FLAGS_EXCLUDE_CERTIFICATES or CREDUI_FLAGS_REQUIRE_SMARTCARD
Return ValueReturns the username and password entered, and a boolean indicating if credential was saved

        
    """
    pass
        

def CredUIPromptForCredentials(TargetName:'str',AuthError:'typing.Any'=0,UserName:'str'=None,Password:'str'=None,Save:'typing.Any'=True,Flags:'typing.Any'=0,UiInfo:'typing.Any'=None) -> 'typing.Tuple[str, str, typing.Any]':
    """
    Initiates dialog to request 

user credentials

Args:

      TargetName(str):Server or domain against which to authenticate
      AuthError(typing.Any):Error code indicating why credentials are required, can be 0
      UserName(str):Default username, can be None.  At most CREDUI_MAX_USERNAME_LENGTH chars
      Password(str):Password, can be None.  At most CREDUI_MAX_PASSWORD_LENGTH chars
      Save(typing.Any):Specifies whether Save checkbox defaults to checked or unchecked
      Flags(typing.Any):Combination of CREDUI_FLAGS_* values
      UiInfo(typing.Any):PyCREDUI_INFO dict for customizing the dialog, can be NoneReturn ValueReturns the username, password, and a boolean indicating if credential was persisted

Returns:

      typing.Tuple[str, str, typing.Any]:PyCREDUI_INFO dict for customizing the dialog, can be None
Return ValueReturns the username, password, and a boolean indicating if credential was persisted

        
    """
    pass
        

def CredUIConfirmCredentials(TargetName:'str',Confirm:'typing.Any') -> 'None':
    """
    Confirms whether credentials entered by user are valid or not

Args:

      TargetName(str):Target of credentials that are pending confirmation
      Confirm(typing.Any):Indicates if authentication succeededCommentsThis function should be called to confirm credentials entered via win32cred::CredUICmdLinePromptForCredentials or win32cred::CredUIPromptForCredentials if CREDUI_FLAGS_EXPECT_CONFIRMATION was passed in Flags to either function. Sequence of operations: Prompt for credentials Authenticate against target using credentials Call this function to indicate if authentication succeeded or not

Returns:

      None
        
    """
    pass
        

def CredUIReadSSOCredW(Realm:'str'=None) -> 'str':
    """
    Retrieves single sign on username

Args:

      Realm(str):Realm for which to read username, can be None

Returns:

      str
        
    """
    pass
        

def CredUIStoreSSOCredW(Realm:'str',Username:'str',Password:'str',Persist:'typing.Any') -> 'None':
    """
    Creates a single sign on credential

Args:

      Realm(str):Realm for which to read username, can be None for default realm
      Username(str):Username for realm
      Password(str):User's password
      Persist(typing.Any):Specifies whether to save credential

Returns:

      None
        
    """
    pass
        

def CredUIParseUserName(UserName:'str') -> 'typing.Tuple[str, str]':
    """
    Parses a full username into domain and 

username

Args:

      UserName(str):Username as returned by win32cred::CredUIPromptForCredentialsReturn ValueReturns the username and domain

Returns:

      typing.Tuple[str, str]:Username as returned by win32cred::CredUIPromptForCredentialsReturn ValueReturns the username and domain

        
    """
    pass
        


__all__=['', 'WTSOpenServer', 'WTSCloseServer', 'WTSQueryUserConfig', 'WTSSetUserConfig', 'WTSEnumerateServers', 'WTSEnumerateSessions', 'WTSLogoffSession', 'WTSDisconnectSession', 'WTSQuerySessionInformation', 'WTSEnumerateProcesses', 'WTSQueryUserToken', 'WTSShutdownSystem', 'WTSTerminateProcess', 'ProcessIdToSessionId', 'WTSGetActiveConsoleSessionId', 'WTSRegisterSessionNotification', 'WTSUnRegisterSessionNotification', 'WTSWaitSystemEvent', 'WTSSendMessage']
import typing
import win32typing
"""Interface to the Terminal Services Api 

All functions in this module accept keyword arguments"""


def WTSOpenServer(ServerName:'str') -> 'int':
    """
    Opens a handle to a terminal server

Args:

      ServerName(str):Name ot terminal server to be opened

Returns:

      int
        
    """
    pass
        

def WTSCloseServer(Server:'int') -> 'None':
    """
    Closes a terminal server handle

Args:

      Server(int):Terminal Server handle

Returns:

      None
        
    """
    pass
        

def WTSQueryUserConfig(ServerName:'str',UserName:'str',ConfigClass:'typing.Any') -> 'typing.Any':
    """
    Returns user configuration

Args:

      ServerName(str):Name ot terminal server
      UserName(str):Name of user
      ConfigClass(typing.Any):Type of information to be returned, win32ts.WTSUserConfig*ConfigClassReturned valueWTSUserConfigInitialProgramUnicode string, program to be run when user logs onWTSUserConfigWorkingDirectoryUnicode string, working dir for initial programWTSUserConfigModemCallbackPhoneNumberUnicode stringWTSUserConfigTerminalServerProfilePathUnicode stringWTSUserConfigTerminalServerHomeDirUnicode stringWTSUserConfigTerminalServerHomeDirDriveUnicode stringWTSUserConfigfInheritInitialProgramIntWTSUserConfigfAllowLogonTerminalServerInt, 1 if user can log on thru Terminal ServiceWTSUserConfigTimeoutSettingsConnectionsInt, max connection time (ms)WTSUserConfigTimeoutSettingsDisconnectionsIntWTSUserConfigTimeoutSettingsIdleInt, max idle time (ms)WTSUserConfigfDeviceClientDrivesIntWTSUserConfigfDeviceClientPrintersIntWTSUserConfigfDeviceClientDefaultPrinterIntWTSUserConfigBrokenTimeoutSettingsIntWTSUserConfigReconnectSettingsIntWTSUserConfigModemCallbackSettingsIntWTSUserConfigShadowingSettingsInt, indicates if user's session my be monitoredWTSUserConfigfTerminalServerRemoteHomeDirInt,Return ValueThe type of the returned value is dependent on the config class requested

Returns:

      typing.Any:Type of information to be returned, win32ts.WTSUserConfig*


ConfigClass


Returned value



WTSUserConfigInitialProgramUnicode string, program to be 

run when user logs on
WTSUserConfigWorkingDirectoryUnicode string, working dir 

for initial program
WTSUserConfigModemCallbackPhoneNumberUnicode 

string
WTSUserConfigTerminalServerProfilePathUnicode 

string
WTSUserConfigTerminalServerHomeDirUnicode string
WTSUserConfigTerminalServerHomeDirDriveUnicode 

string
WTSUserConfigfInheritInitialProgramInt
WTSUserConfigfAllowLogonTerminalServerInt, 1 if 

user can log on thru Terminal Service
WTSUserConfigTimeoutSettingsConnectionsInt, 

max connection time (ms)
WTSUserConfigTimeoutSettingsDisconnectionsInt
WTSUserConfigTimeoutSettingsIdleInt, max idle time 

(ms)
WTSUserConfigfDeviceClientDrivesInt
WTSUserConfigfDeviceClientPrintersInt
WTSUserConfigfDeviceClientDefaultPrinterInt
WTSUserConfigBrokenTimeoutSettingsInt
WTSUserConfigReconnectSettingsInt
WTSUserConfigModemCallbackSettingsInt
WTSUserConfigShadowingSettingsInt, indicates if user's 

session my be monitored
WTSUserConfigfTerminalServerRemoteHomeDirInt,
Return ValueThe type of the returned value is dependent on the config class requested

        
    """
    pass
        

def WTSSetUserConfig(ServerName:'str',UserName:'str',ConfigClass:'typing.Any') -> 'None':
    """
    Changes user configuration

Args:

      ServerName(str):Name ot terminal server
      UserName(str):Name of user
      ConfigClass(typing.Any):Type of information to be set, win32ts.WTSUserConfig*ConfigClassType of data requiredWTSUserConfigInitialProgramUnicode string, program to be run when user logs onWTSUserConfigWorkingDirectoryUnicode string, working dir for initial programWTSUserConfigModemCallbackPhoneNumberUnicode stringWTSUserConfigTerminalServerProfilePathUnicode stringWTSUserConfigTerminalServerHomeDirUnicode stringWTSUserConfigTerminalServerHomeDirDriveUnicode stringWTSUserConfigfInheritInitialProgramIntWTSUserConfigfAllowLogonTerminalServerInt, 1 if user can log on thru Terminal ServiceWTSUserConfigTimeoutSettingsConnectionsInt, max connection time (ms)WTSUserConfigTimeoutSettingsDisconnectionsIntWTSUserConfigTimeoutSettingsIdleInt, max idle time (ms)WTSUserConfigfDeviceClientDrivesIntWTSUserConfigfDeviceClientPrintersIntWTSUserConfigfDeviceClientDefaultPrinterIntWTSUserConfigBrokenTimeoutSettingsIntWTSUserConfigReconnectSettingsIntWTSUserConfigModemCallbackSettingsIntWTSUserConfigShadowingSettingsInt, indicates if user's session my be monitoredWTSUserConfigfTerminalServerRemoteHomeDirInt,

Returns:

      None
        
    """
    pass
        

def WTSEnumerateServers(DomainName:'str'=None,Version:'typing.Any'=1,Reserved:'typing.Any'=0) -> 'typing.Tuple[str, ...]':
    """
    Lists terminal servers in a domain

Args:

      DomainName(str):Use None for current domain
      Version(typing.Any):Version of request, currently 1 is only valid value
      Reserved(typing.Any):Reserved, use 0 if passed in

Returns:

      typing.Tuple[str, ...]
        
    """
    pass
        

def WTSEnumerateSessions(Server:'int',Version:'typing.Any'=1,Reserved:'typing.Any'=0) -> 'typing.Tuple[typing.Any, ...]':
    """
    Lists sessions on a server

Args:

      Server(int):Handle to a terminal server
      Version(typing.Any):Version of request, currently 1 is only valid value
      Reserved(typing.Any):Reserved, use 0 if passed inReturn ValueReturns a sequence of dictionaries representing WTS_SESSION_INFO structs, containing {SessionId:int, WinStationName:str, State:int}

Returns:

      typing.Tuple[typing.Any, ...]:Reserved, use 0 if passed in
Return ValueReturns a sequence of dictionaries representing WTS_SESSION_INFO structs, containing {SessionId:int, 

WinStationName:str, State:int}

        
    """
    pass
        

def WTSLogoffSession(Server:'int',SessionId:'typing.Any',Wait:'typing.Any') -> 'None':
    """
    Logs off a user logged in through Terminal Services

Args:

      Server(int):Handle to a terminal server
      SessionId(typing.Any):Terminal services session id as returned by win32ts::WTSEnumerateSessions
      Wait(typing.Any):Indicates whether operation should be performed asynchronously

Returns:

      None
        
    """
    pass
        

def WTSDisconnectSession(Server:'int',SessionId:'typing.Any',Wait:'typing.Any') -> 'None':
    """
    Disconnects a session without logging it off

Args:

      Server(int):Handle to a terminal server
      SessionId(typing.Any):Terminal services session id as returned by win32ts::WTSEnumerateSessions
      Wait(typing.Any):Indicates whether operation should be performed asynchronously

Returns:

      None
        
    """
    pass
        

def WTSQuerySessionInformation(Server:'int',SessionId:'typing.Any',WTSInfoClass:'typing.Any') -> 'None':
    """
    Returns information about a terminal services session

Args:

      Server(int):Handle to a terminal server as returned by win32ts::WTSOpenServer
      SessionId(typing.Any):Terminal services session id as returned by win32ts::WTSEnumerateSessions
      WTSInfoClass(typing.Any):Type of information requested, from WTS_INFO_CLASS enumInfoClassReturned valueWTSApplicationNameUnicode stringWTSClientDirectoryUnicode stringWTSClientNameUnicode stringWTSDomainNameUnicode stringWTSInitialProgramUnicode stringWTSOEMIdUnicode stringWTSUserNameUnicode stringWTSWinStationNameUnicode stringWTSWorkingDirectoryUnicode stringWTSClientProtocolTypeInt, one of WTS_PROTOCOL_TYPE_CONSOLE,WTS_PROTOCOL_TYPE_ICA,WTS_PROTOCOL_TYPE_RDPWTSClientProductIdIntWTSClientBuildNumberIntWTSClientHardwareIdIntWTSSessionIdIntWTSConnectStateInt, from WTS_CONNECTSTATE_CLASSWTSClientDisplayDict containing client's display settingsWTSClientAddressDict containing type and value of client's IP address (None if console session) IPV6 addresses may not be returned correctly on Windows versions earlier than Windows Server 2012 (see http://sourceforge.net/p/pywin32/bugs/664/ for details)

Returns:

      None
        
    """
    pass
        

def WTSEnumerateProcesses(Server:'int',Version:'typing.Any'=1,Reserved:'typing.Any'=0) -> 'typing.Tuple[str, ...]':
    """
    Lists processes on a terminal server

Args:

      Server(int):Handle to a terminal server
      Version(typing.Any):Version of request, currently 1 is only valid value
      Reserved(typing.Any):Reserved, use 0 if passed in

Returns:

      typing.Tuple[str, ...]
        
    """
    pass
        

def WTSQueryUserToken(SessionId:'typing.Any') -> 'int':
    """
    Retrieves the access token for a session

Args:

      SessionId(typing.Any):Terminal services session idCommentsThis function is intended only for use by trusted processes that have SE_TCB_PRIVILEGE enabled

Returns:

      int
        
    """
    pass
        

def WTSShutdownSystem(Server:'int',ShutdownFlag:'typing.Any') -> 'None':
    """
    Issues a shutdown request to a terminal server

Args:

      Server(int):Handle to a terminal server
      ShutdownFlag(typing.Any):One of the win32ts.WTS_WSD_* values

Returns:

      None
        
    """
    pass
        

def WTSTerminateProcess(Server:'int',ProcessId:'typing.Any',ExitCode:'typing.Any') -> 'None':
    """
    Kills a process on a terminal server

Args:

      Server(int):Handle to a terminal server
      ProcessId(typing.Any):Id of a process as returned by win32ts::WTSEnumerateProcesses
      ExitCode(typing.Any):Exit code for the process

Returns:

      None
        
    """
    pass
        

def ProcessIdToSessionId(ProcessId:'typing.Any') -> 'typing.Any':
    """
    Finds the session under which a process is running

Args:

      ProcessId(typing.Any):Id of a process as returned by win32ts::WTSEnumerateProcesses

Returns:

      typing.Any
        
    """
    pass
        

def WTSGetActiveConsoleSessionId() -> 'typing.Any':
    """
    Returns the id of the console session

Args:



Returns:

      typing.Any
        
    """
    pass
        

def WTSRegisterSessionNotification(Wnd:'int',Flags:'typing.Any') -> 'None':
    """
    Registers a window to receive terminal service notifications

Args:

      Wnd(int):Window handle to receive terminal service messages
      Flags(typing.Any):NOTIFY_FOR_THIS_SESSION or NOTIFY_FOR_ALL_SESSIONS

Returns:

      None
        
    """
    pass
        

def WTSUnRegisterSessionNotification(Wnd:'int') -> 'None':
    """
    Disables terminal service window messages

Args:

      Wnd(int):Window previously registered to receive session notifications

Returns:

      None
        
    """
    pass
        

def WTSWaitSystemEvent(Server:'int',EventMask:'typing.Any') -> 'typing.Any':
    """
    Waits for an event to occur

Args:

      Server(int):Handle to a terminal server, or WTS_CURRENT_SERVER_HANDLE
      EventMask(typing.Any):Combination of WTS_EVENT_* valuesReturn ValueReturns a bitmask of WTS_EVENT_* flags indication which event(s) occurred

Returns:

      typing.Any:Combination of WTS_EVENT_* values
Return ValueReturns a bitmask of WTS_EVENT_* flags indication which event(s) occurred

        
    """
    pass
        

def WTSSendMessage(Server:'int',SessionId:'typing.Any',Title:'str',Message:'str',Style:'typing.Any',Timeout:'typing.Any',Wait:'typing.Any') -> 'typing.Any':
    """
    Sends a popup message to a terminal services session

Args:

      Server(int):Handle to a terminal server, or WTS_CURRENT_SERVER_HANDLE
      SessionId(typing.Any):Terminal services session id
      Title(str):Title of dialog
      Message(str):Message to be displayed
      Style(typing.Any):Usually MB_OK
      Timeout(typing.Any):Seconds to wait before returning (only used if Wait is True)
      Wait(typing.Any):Specifies if function should wait for user input before returningReturn ValueReturns one of IDABORT,IDCANCEL,IDIGNORE,IDNO,IDOK,IDRETRY,IDYES,IDASYNC,IDTIMEOUT,

Returns:

      typing.Any:Specifies if function should wait for user input before returningReturn ValueReturns one of IDABORT,IDCANCEL,IDIGNORE,IDNO,IDOK,IDRETRY,IDYES,IDASYNC,IDTIMEOUT,

        
    """
    pass
        


__all__=['', 'mmapfile']
import typing
import win32typing
"""Compiled extension module that provides access to the memory mapped file API"""


def mmapfile(File:'typing.Any',Name:'typing.Any',MaximumSize:'typing.Any'=0,FileOffset:'typing.Any'=0,NumberOfBytesToMap:'typing.Any'=0) -> 'win32typing.Pymmapfile':
    """
    Creates or opens a memory mapped file. 

This method uses the following API functions: CreateFileMapping, MapViewOfFile, VirtualQuery

Args:

      File(typing.Any):Name of file.  Use None or '' when opening an existing named mapping, or to use system pagefile.
      Name(typing.Any):Name of mapping object to create or open, can be None
      MaximumSize(typing.Any):Size of file mapping to create, should be specified as a multiple of system page size (see win32api::GetSystemInfo).  Defaults to size of existing file if 0. If an existing named mapping is opened, the returned object will have the same size as the original mapping.
      FileOffset(typing.Any):Offset into the file at which to create view.  This should be specified as a multiple of system allocation granularity. (see win32api::GetSystemInfo)
      NumberOfBytesToMap(typing.Any):Size of view to create, also a multiple of system page size. If 0, view will span from offset to end of file mapping.CommentsAccepts keyword args.Win32 API References

Returns:

      win32typing.Pymmapfile
        
    """
    pass
        


__all__=['', 'ADsOpenObject', 'ADsGetObject', 'ADsBuildEnumerator', 'ADsEnumerateNext', 'ADsGetLastError', 'StringAsDS_SELECTION_LIST', 'DSOP_SCOPE_INIT_INFOs']
import typing
import win32typing
"""A COM interface to ADSI"""


def ADsOpenObject(path:'typing.Any',username:'typing.Any',password:'typing.Any',iid:'win32typing.PyIID',reserved:'typing.Any'=0) -> 'typing.Any':
    """
    Binds to an ADSI object using explicit username and password credentials.

Args:

      path(typing.Any):
      username(typing.Any):
      password(typing.Any):
      iid(win32typing.PyIID):The requested interface
      reserved(typing.Any):

Returns:

      typing.Any
        
    """
    pass
        

def ADsGetObject(path:'typing.Any',iid:'win32typing.PyIID') -> 'typing.Any':
    """
    Binds to an object given its path and a specified interface identifier (IID).

Args:

      path(typing.Any):
      iid(win32typing.PyIID):The requested interface

Returns:

      typing.Any
        
    """
    pass
        

def ADsBuildEnumerator(container:'win32typing.PyIADsContainer') -> 'typing.Any':
    """
    Builds an enumerator object for the specified ADSI container object.

Args:

      container(win32typing.PyIADsContainer):

Returns:

      typing.Any
        
    """
    pass
        

def ADsEnumerateNext(enum:'typing.Any',num:'typing.Any'=1) -> 'typing.Any':
    """
    None

Args:

      enum(typing.Any):The enumerator.
      num(typing.Any):Number of items to retrieve.Return ValueThe result is a tuple of Python objects converted from Variants, one for each element returned.  Note that if zero elements are returned, it is not considered an error condition - an empty tuple is simply returned.

Returns:

      typing.Any:Number of items to retrieve.
Return ValueThe result is a tuple of Python objects converted from Variants, 

one for each element returned.  Note that if zero elements are returned, it is not considered 

an error condition - an empty tuple is simply returned.

        
    """
    pass
        

def ADsGetLastError() -> 'typing.Tuple[typing.Any, typing.Any, typing.Any]':
    """
    None

Args:



Returns:

      typing.Tuple[typing.Any, typing.Any, typing.Any]
        
    """
    pass
        

def StringAsDS_SELECTION_LIST(buf:'typing.Any') -> 'typing.Any':
    """
    None

Args:

      buf(typing.Any):The raw buffer

Returns:

      typing.Any
        
    """
    pass
        

def DSOP_SCOPE_INIT_INFOs(size:'typing.Any') -> 'typing.Any':
    """
    None

Args:

      size(typing.Any):The number of PyDSOP_SCOPE_INIT_INFO objects to create in the array.

Returns:

      typing.Any
        
    """
    pass
        


__all__=['', 'NCBBuffer', 'Netbios', 'WNetAddConnection2', 'WNetAddConnection3', 'WNetCancelConnection2', 'WNetOpenEnum', 'WNetCloseEnum', 'WNetEnumResource', 'WNetGetUser', 'WNetGetUniversalName', 'WNetGetResourceInformation', 'WNetGetLastError', 'WNetGetResourceParent', 'WNetGetConnection']
import typing
import win32typing
"""A module that exposes the Windows Networking API."""


def NCBBuffer(size:'typing.Any') -> 'typing.Any':
    """
    Creates an NCB buffer of the relevant size.

Args:

      size(typing.Any):The number of bytes to allocate.

Returns:

      typing.Any
        
    """
    pass
        

def Netbios(ncb:'win32typing.NCB') -> 'typing.Any':
    """
    Executes a Netbios call.

Args:

      ncb(win32typing.NCB):The NCB object to use for the call.

Returns:

      typing.Any
        
    """
    pass
        

def WNetAddConnection2(NetResource:'win32typing.PyNETRESOURCE',Password:'typing.Any'=None,UserName:'typing.Any'=None,Flags:'typing.Any'=0) -> 'None':
    """
    Creates a connection to a network resource. The function can redirect 

a local device to the network resource.

Args:

      NetResource(win32typing.PyNETRESOURCE):Describes the network resource for the connection.
      Password(typing.Any):The password to use.  Use None for default credentials.
      UserName(typing.Any):The user name to connect as.  Use None for default credentials.
      Flags(typing.Any):Combination win32netcon.CONNECT_* flagsCommentsThis function also accepts backwards-compatible, positional-only arguments of (dwType, lpLocalName, lpRemoteName[, lpProviderName, Username, Password, flags])Accepts keyword arguments.Win32 API References

Returns:

      None
        
    """
    pass
        

def WNetAddConnection3(hwnd:'int',NetResource:'win32typing.PyNETRESOURCE',Password:'typing.Any'=None,UserName:'typing.Any'=None,Flags:'typing.Any'=0) -> 'None':
    """
    Creates a connection to a network resource.

Args:

      hwnd(typing.Any):Handle to a parent window.
      NetResource(win32typing.PyNETRESOURCE):Describes the network resource for the connection.
      Password(typing.Any):The password to use.  Use None for default credentials.
      UserName(typing.Any):The user name to connect as.  Use None for default credentials.
      Flags(typing.Any):Combination win32netcon.CONNECT_* flagsCommentsAccepts keyword arguments.Win32 API References

Returns:

      None
        
    """
    pass
        

def WNetCancelConnection2(name:'str',flags:'typing.Any',force:'typing.Any') -> 'None':
    """
    Closes network connections made by WNetAddConnection2 or 3

Args:

      name(str):Name of existing connection to be closed
      flags(typing.Any):Currently determines if the persisent connection information will be updated as a result of this call.
      force(typing.Any):indicates if the close operation should be forced. (i.e. ignore open files and connections)

Returns:

      None
        
    """
    pass
        

def WNetOpenEnum(scope:'typing.Any',_type:'typing.Any',usage:'typing.Any',resource:'win32typing.PyNETRESOURCE') -> 'int':
    """
    None

Args:

      scope(typing.Any):Specifies the scope of the enumeration.
      _type(typing.Any):Specifies the resource types to enumerate.
      usage(typing.Any):Specifies the resource usage to be enumerated.
      resource(win32typing.PyNETRESOURCE):Python NETRESOURCE object.CommentsSee the Microsoft SDK  for complete information on WNetOpenEnum.Return ValuePyHANDLE representing the Win32 HANDLE for the open resource. This handle will be automatically be closed via win32wnet::WNetCloseEnum, but good style dictates it still be closed manually.

Returns:

      int:Python NETRESOURCE object.Comments

See the Microsoft SDK  for complete information on WNetOpenEnum.
Return ValuePyHANDLE representing the Win32 HANDLE for the open resource. 

This handle will be automatically be closed via win32wnet::WNetCloseEnum, but 

good style dictates it still be closed manually.

        
    """
    pass
        

def WNetCloseEnum(handle:'int') -> 'None':
    """
    None

Args:

      handle(int):The handle to close, as obtained from win32wnet::WNetOpenEnumCommentsYou should perform a WNetClose for each handle returned from win32wnet::WNetOpenEnum.

Returns:

      None
        
    """
    pass
        

def WNetEnumResource(handle:'int',maxExtries:'typing.Any'=64) -> 'typing.List[win32typing.PyNETRESOURCE]':
    """
    Enumerates a list of resources

Args:

      handle(int):A handle to an open Enumeration Object (from win32wnet::WNetOpenEnum)
      maxExtries(typing.Any):The maximum number of entries to return.CommentsSuccessive calls to win32wnet.WNetEnumResource will enumerate starting where the previous call stopped. That is, the enumeration is not reset on successive calls UNLESS the enumeration handle is closed and reopened.  This lets you process an enumeration in small chunks (as small as 1 item at a time) and still fully enumerate a network object!Return ValueThe list contains PyNETRESOURCE entries. The total number of PyNETRESOURCE entries will be &lt= number requested (excepting the default behavior of requesting 0, which returns up to 64)

Returns:

      typing.List[win32typing.PyNETRESOURCE]:The maximum number of entries to return.
Comments

Successive calls to win32wnet.WNetEnumResource will enumerate starting where the previous call 

stopped. That is, the enumeration is not reset on successive calls UNLESS the enumeration handle is 

closed and reopened.  This lets you process an enumeration in small chunks (as small as 1 item at a time) 

and still fully enumerate a network object!
Return ValueThe list contains PyNETRESOURCE entries. The total number of PyNETRESOURCE entries will be &lt= number 

requested (excepting the default behavior of requesting 0, which returns up to 64)

        
    """
    pass
        

def WNetGetUser(connection:'str'=None) -> 'str':
    """
    Retrieves the current default user name, or the user name used to establish a 

network connection.

Args:

      connection(str):A string that specifies either the name of a local device that has been redirected to a network resource, or the remote name of a network resource to which a connection has been made without redirecting a local device. If this parameter is None, the system returns the name of the current user for the process.

Returns:

      str
        
    """
    pass
        

def WNetGetUniversalName(localPath:'str',infoLevel:'typing.Any') -> 'typing.Union[str, typing.Any]':
    """
    Takes a drive-based path for a network resource and returns an 

information structure that contains a more universal form of the name.

Args:

      localPath(str):A string that is a drive-based path for a network resource. For example, if drive H has been mapped to a network drive share, and the network resource of interest is a file named SAMPLE.DOC in the directory \\WIN32\\EXAMPLES on that share, the drive-based path is H:\\WIN32\\EXAMPLES\\SAMPLE.DOC.
      infoLevel(typing.Any):Specifies the type of structure that the function stores in the buffer pointed to by the lpBuffer parameter. This parameter can be one of the following values.ValueMeaningUNIVERSAL_NAME_INFO_LEVEL (=1)The function returns a simple string with the UNC name.REMOTE_NAME_INFO_LEVEL (=2)The function returns a tuple based in the Win32 REMOTE_NAME_INFO data structure.Return ValueIf the infoLevel parameter is REMOTE_NAME_INFO_LEVEL, the result is a tuple of 3 strings: (UNCName, connectionName, remainingPath)

Returns:

      typing.Union[str, typing.Any]:Specifies the type of structure that the function stores in the 

buffer pointed to by the lpBuffer parameter. This parameter can be one of the following values.



Value


Meaning



UNIVERSAL_NAME_INFO_LEVEL (=1)The function returns a simple string with the UNC name.
REMOTE_NAME_INFO_LEVEL (=2)The function returns a tuple based in the Win32 REMOTE_NAME_INFO data 

structure.
Return ValueIf the infoLevel parameter is REMOTE_NAME_INFO_LEVEL, the result is a tuple of 3 strings: (UNCName, 

connectionName, remainingPath)

        
    """
    pass
        

def WNetGetResourceInformation(NetResource:'win32typing.PyNETRESOURCE') -> 'typing.Tuple[win32typing.PyNETRESOURCE, typing.Any]':
    """
    Finds the type and provider of a network 

resource

Args:

      NetResource(win32typing.PyNETRESOURCE):Describes a network resource.  lpRemoteName is required, dwType and lpProvider can be supplied if knownReturn ValueReturns a NETRESOURCE and a string containing the trailing part of the remote path

Returns:

      typing.Tuple[win32typing.PyNETRESOURCE, typing.Any]:Describes a network resource.  lpRemoteName 

is required, dwType and lpProvider can be supplied if knownReturn ValueReturns a NETRESOURCE and a string containing the trailing part of the remote path

        
    """
    pass
        

def WNetGetLastError() -> 'typing.Tuple[typing.Any, typing.Any, typing.Any]':
    """
    Retrieves extended error information set by a network provider 

when one of the WNet* functions fails

Args:



Returns:

      typing.Tuple[typing.Any, typing.Any, typing.Any]:win32wnet.WNetGetLastError

(int,str,str) = WNetGetLastError()Retrieves extended error information set by a network provider 

when one of the WNet* functions fails
Comments

The error description or the network provider name may be truncated if they exceed 1024 and 256 characters, 

respectively
Return ValueReturns the error code, a text description of the error, and the name of the network provider

        
    """
    pass
        

def WNetGetResourceParent(NetResource:'win32typing.PyNETRESOURCE') -> 'win32typing.PyNETRESOURCE':
    """
    Finds the parent resource of a network resource

Args:

      NetResource(win32typing.PyNETRESOURCE):Describes a network resource.  lpRemoteName and lpProvider are required, dwType is recommended for efficiency

Returns:

      win32typing.PyNETRESOURCE
        
    """
    pass
        

def WNetGetConnection(connection:'str'=None) -> 'str':
    """
    Retrieves the name of the network resource associated with a local 

device.

Args:

      connection(str):A string that is a drive-based path for a network resource. For example, if drive H has been mapped to a network drive share, and the network resource of interest is a file named Sample.doc in the directory \\Win32\\Examples on that share, the drive-based path is H:\\Win32\\Examples\\Sample.doc.

Returns:

      str
        
    """
    pass
        